@@ -63,7 +63,7 @@ class hassd_mqtt(mqtt):
                     payload.update({"state_class": "measurement", "device_class": "power"})
                 # msg = {"topic": topic, "payload": payload, "retain": True}
                 payloads = js.dumps(payload)
-                print(payloads)
+                # print(payloads)
                 msg = {"topic": topic, "payload": payloads}
                 msgs.append(msg)
                 #
