@@ -465,7 +465,7 @@ COMMANDS = {
         "type": "QUERY",
         "response": [["string", "Max Charging Current", "A"]],
         "test_responses": [
-            b"",
+            b"(010 020 030 040 050 060 070 080 090 100 110 120\x0c\xcb\r",
         ],
     },
     "QMOD": {
@@ -498,7 +498,7 @@ COMMANDS = {
         "type": "QUERY",
         "response": [["string", "Max Utility Charging Current", "A"]],
         "test_responses": [
-            b"",
+            b"(002 010 020 030 040 050 060 070 080 090 100 110 120\xca#\r",
         ],
     },
     "QOPM": {
@@ -880,6 +880,9 @@ COMMANDS = {
 
 
 class pi30(AbstractProtocol):
+    def __str__(self):
+        return "PI30 protocol handler"
+
     def __init__(self, *args, **kwargs) -> None:
         super().__init__()
         self._protocol_id = b"PI30"
